@@ -1,18 +1,22 @@
 #
-# $Id: Factor.pm,v 0.02 2004/01/06 13:59:18 sts Exp $
+# $Id: Factor.pm,v 0.03 2004/01/06 17:26:07 sts Exp $
 
 package Math::Factor;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use integer;
 use strict;
 use warnings;
 
+our ($format_factors, $format_match_number,
+     $format_match_matches);
+
 use Exporter;
 use base qw(Exporter);
 
-our (@EXPORT_OK, %EXPORT_TAGS, @subs_factor, @subs_match, @subs);
+our (@EXPORT_OK, %EXPORT_TAGS, @subs_factor,
+     @subs_match, @subs);
 
 @subs_factor = qw(factor show_factor);
 @subs_match = qw(match show_match);
@@ -127,9 +131,9 @@ Outputs all numbers and their according factors to STDOUT.
 
  show_factor (\%factors);
 
-   9
-   -
-   1    3    9
+ 9
+ -
+ 1 3 9
 
 =cut
 
@@ -138,22 +142,20 @@ sub show_factor {
     croak q~usage: show_factors (\%factors)~
       unless ref $number_ref eq 'HASH' && %$number_ref;
 
-    print <<'EOT';
+    print <<'HEADER';
 -------
 FACTORS
 -------
 
-EOT
-    local $" = "\t";
+HEADER
+
+    my $ul;
+    eval $format_factors;
+    croak $@ if $@;
+
     foreach (sort {$a <=> $b} keys %$number_ref) {
-        my $ul = '-' x length;
-        print <<"EOT";
-$_
-$ul
-@{$$number_ref{$_}}
-
-
-EOT
+        $ul = '-' x length;
+        write;
     }
 }
 
@@ -163,10 +165,10 @@ Outputs all numbers and their according matching multiplications to STDOUT.
 
  show_match (\%matches);
 
-   9
-   -
-   1 * 9
-   3 * 3
+ 9
+ -
+         1        * 9
+         3        * 3
 
 =cut
 
@@ -175,28 +177,63 @@ sub show_match {
     croak q~usage: show_match (\%match)~
       unless ref $number_ref eq 'HASH' && %$number_ref;
 
-    print <<'EOT';
+    print <<'HEADER';
 -------
 MATCHES
 -------
 
-EOT
+HEADER
+
+    no warnings;
     foreach (sort {$a <=> $b} keys %$number_ref) {
         my $ul = '-' x length;
-        print <<"EOT";
-$_
-$ul
-EOT
-    for (my $i = 0; $$number_ref{$_}[$i]; $i++) {
-        print "$$number_ref{$_}[$i][0] * $$number_ref{$_}[$i][1]\n";
-    }
-    print <<'EOT';
+
+        eval $format_match_number;
+        croak $@ if $@;
+        write;
+
+        my $i;
+        eval $format_match_matches;
+        croak $@ if $@;
+
+        for ($i = 0; $$number_ref{$_}[$i]; $i++) { write }
+
+        print <<'WHITESPACE';
 
 
-EOT
+WHITESPACE
     }
 }
 
+$format_factors = '
+    format =
+@<<<<<<<<<<<<<<<<<<<<<<<<<
+$_
+@<<<<<<<<<<<<<<<<<<<<<<<<<
+$ul
+@<<<<<<<<<<<<<<<<<<<<<<<<<
+"@{$$number_ref{$_}}"
+
+
+.
+';
+
+$format_match_number = '
+    format =
+@<<<<<<<<<<<<<<<<<<<<<<<<<
+$_
+@<<<<<<<<<<<<<<<<<<<<<<<<<
+$ul
+.
+';
+
+$format_match_matches = '
+    format =
+        @<<<<<<<<* @<<<<<<<<<<<<<<<<<<<<<
+        $$number_ref{$_}[$i][0] $$number_ref{$_}[$i][1]
+.
+';
+
 1;
 __END__
 
